Crate iota_stronghold

Crate iota_stronghold 

Stronghold Client Interface

The client interface exposes all functionality to work with a Stronghold instance

Re-exports

pub use crate::internal::Provider;
pub use engine;
pub use crate::security::*;
pub use crate::types::*;
pub use crate::utils::*;

Modules

internal
procedures
security
sync
types
A collection of relevant interface types to interact with a Stronghold
utils

Macros

generic_procedures
procedures
Implement StrongholdProcedure: From<T> for all. Implement Procedure if $Trait:ident != _.

Enums

MemoryError
The different types of Error that may be encountered while using this crate